/*  Last edited: Mar 16 17:36 1997 (birney) */


#ifndef DYNAMITEHELPERHEADERFILE
#define DYNAMITEHELPERHEADERFILE


/*** this file includes all the correct files
  for libdyn linking ***/


#include "packaln.h"
#include "basematrix.h"
#include "shattermatrix.h"
#include "dpenvelope.h"
#include "dbsearchimpl.h"
#include "dprunimpl.h"
#include "matrixdebug.h"
#include "shattermatrix.h"

#include "sequence.h"
#include "seqalign.h"
#include "proteindb.h"
#include "database.h"
#include "hscore.h"
#include "histogram.h"
#include "searchstatinterface.h"
#include "searchstatlookup.h"
#include "aln.h"
#include "linesubs.h"
#include "complexsequence.h"
#include "complexevalset.h"
#include "complexconsensi.h"
#include "codon.h"
#include "codonmapper.h"
#include "alnconvert.h"
#include "alnrange.h"
#include "compmat.h"
#include "codonmatrix.h"
#include "dnamatrix.h"
#include "protein.h"
#include "genomic.h"
#include "genomicdb.h"
#include "cdna.h"
#include "cdnadb.h"
#include "dna.h"

#include "seqlookup.h"
#include "arrayseqlookup.h"
#include "proteinstreamedindex.h"

#include "embl.h"
#include "genomicregion.h"
#include "gene.h"
#include "transcript.h"
#include "translation.h"

#include "btcanvas.h"
#include "asciibtcanvas.h"

#include "dynlibcross.h"

#include "matrixdebug.h"

#endif






